==> cscec5b-wzxt-api-3.0.1-20220318.150340-56-sources.jar: com/ejianc/business/wzxt/vo/ExitReportVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;


/**
 * 周转材进出场台账表
 * 
 * @author syj
 * 
 */
public class ExitReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Long pId;
    private String BillCode; // 编码
    private String construction; // 施工部位
    private String materialName; // 物资名称
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private int type; // 类型 0-进场 1-退场
    private String typeName; // 类型 0-进场 1-退场
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date exitDate; // 进/退场日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date startDate; // 起/止租日

    private java.math.BigDecimal controlNums;
    private java.math.BigDecimal planNums;
    private java.math.BigDecimal orderNums;
    private java.math.BigDecimal checkNums;
    private java.math.BigDecimal exitNums;
    private java.math.BigDecimal zcNums;
    private java.math.BigDecimal rate;

    public Long getpId() {
        return pId;
    }

    public void setpId(Long pId) {
        this.pId = pId;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }

    public BigDecimal getZcNums() {
        return zcNums;
    }

    public void setZcNums(BigDecimal zcNums) {
        this.zcNums = zcNums;
    }

    public BigDecimal getControlNums() {
        return controlNums;
    }

    public void setControlNums(BigDecimal controlNums) {
        this.controlNums = controlNums;
    }

    public BigDecimal getPlanNums() {
        return planNums;
    }

    public void setPlanNums(BigDecimal planNums) {
        this.planNums = planNums;
    }

    public BigDecimal getOrderNums() {
        return orderNums;
    }

    public void setOrderNums(BigDecimal orderNums) {
        this.orderNums = orderNums;
    }

    public BigDecimal getCheckNums() {
        return checkNums;
    }

    public void setCheckNums(BigDecimal checkNums) {
        this.checkNums = checkNums;
    }

    public BigDecimal getExitNums() {
        return exitNums;
    }

    public void setExitNums(BigDecimal exitNums) {
        this.exitNums = exitNums;
    }

    public String getBillCode() {
        return BillCode;
    }

    public void setBillCode(String billCode) {
        BillCode = billCode;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public Date getExitDate() {
        return exitDate;
    }

    public void setExitDate(Date exitDate) {
        this.exitDate = exitDate;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }
}

==> cscec5b-wzxt-api-3.0.1-20220507.142925-90-sources.jar: com/ejianc/business/wzxt/vo/ExitReportVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;


/**
 * 周转材进出场台账表
 * 
 * @author syj
 * 
 */
public class ExitReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Long pId;
    private String BillCode; // 编码
    private String projectId;      // 项目ID
    private String projectName;   // 项目名称
    private String construction; // 施工部位
    private String materialName; // 物资名称
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private int type; // 类型 0-进场 1-退场
    private String typeName; // 类型 0-进场 1-退场
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date exitDate; // 进/退场日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date startDate; // 起/止租日

    private java.math.BigDecimal controlNums;
    private java.math.BigDecimal planNums;
    private java.math.BigDecimal orderNums;
    private java.math.BigDecimal checkNums;
    private java.math.BigDecimal exitNums;
    private java.math.BigDecimal zcNums;
    private java.math.BigDecimal rate;

    public Long getpId() {
        return pId;
    }

    public void setpId(Long pId) {
        this.pId = pId;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }

    public BigDecimal getZcNums() {
        return zcNums;
    }

    public void setZcNums(BigDecimal zcNums) {
        this.zcNums = zcNums;
    }

    public BigDecimal getControlNums() {
        return controlNums;
    }

    public void setControlNums(BigDecimal controlNums) {
        this.controlNums = controlNums;
    }

    public BigDecimal getPlanNums() {
        return planNums;
    }

    public void setPlanNums(BigDecimal planNums) {
        this.planNums = planNums;
    }

    public BigDecimal getOrderNums() {
        return orderNums;
    }

    public void setOrderNums(BigDecimal orderNums) {
        this.orderNums = orderNums;
    }

    public BigDecimal getCheckNums() {
        return checkNums;
    }

    public void setCheckNums(BigDecimal checkNums) {
        this.checkNums = checkNums;
    }

    public BigDecimal getExitNums() {
        return exitNums;
    }

    public void setExitNums(BigDecimal exitNums) {
        this.exitNums = exitNums;
    }

    public String getBillCode() {
        return BillCode;
    }

    public void setBillCode(String billCode) {
        BillCode = billCode;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public Date getExitDate() {
        return exitDate;
    }

    public void setExitDate(Date exitDate) {
        this.exitDate = exitDate;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }
}
